@@ -32,7 +32,9 @@ NO <-function (mu.link ="identity", sigma.link="log")
         sigma.initial = expression({sigma <- rep(sd(y),length(y))}), 
              mu.valid = function(mu) TRUE , 
           sigma.valid = function(sigma) all(sigma > 0), 
-              y.valid = function(y)  TRUE
+              y.valid = function(y)  TRUE,
+                 mean = function(mu, sigma) mu,
+             variance = function(mu, sigma) sigma^2
           ),
             class = c("gamlss.family","family"))
 }
@@ -104,7 +106,9 @@ rNO <- function(n, mu=0, sigma=1)
         sigma.initial = expression({sigma <- rep(var(y),length(y)) }), 
              mu.valid = function(mu) TRUE , 
           sigma.valid = function(sigma)  all(sigma > 0), 
-              y.valid = function(y)  TRUE
+              y.valid = function(y)  TRUE,
+                 mean = function(mu, sigma) mu,
+             variance = function(mu, sigma) sigma
           ),
             class = c("gamlss.family","family"))
 }
